@echo off
REM
REM BEGIN COPYRIGHT
REM *************************************************************************
REM Licensed Materials - Property of IBM 
REM 5724-L01, 5655-N53, 5724-I82, 5655-R15
REM (C) Copyright IBM Corporation 2006, 2009. All rights reserved. 
REM US Government Users Restricted Rights - Use, duplication, or disclosure
REM restricted by GSA ADP Schedule Contract with IBM Corp.
REM *************************************************************************
REM END COPYRIGHT
   
REM --------------------------------------------------------------------------
REM Description:   Executes the db2cmd configCommonDB.bat scripts to create
REM the CommonDB database.
REM 
REM Usage: 
REM  configCommonDB.bat [createDB]
REM
REM Parameters:
REM 	createDB    - specify whether or not  to create a new db 
REM
REM Example:
REM 	configCommonDB.bat  createDB   //create a new db
REM 	configCommonDB.bat                    // use an existing db
REM     
REM Run the script always where it is located rather running from different folder 
REM
REM Make sure database setup correctly on windows system and  DB2 executables are in the 
REM classpath before executing this script or manageprofiles  command or PMT tool. This is 
REM needed to invoke db2cmd command for  creating a new database. Always run this script 
REM rather than running individual sql script else some tables might be created in wrong schema              
REM Return Codes:  0 for success
REM --------------------------------------------------------------------------

setlocal

SET CUR_DIR=%cd%

%~d0
cd %~p0

set DB_CREATE=%1

REM ==========================================
REM DB_NAME will be replaced 
REM ==========================================
set DB_NAME=@DB_NAME@

REM ==========================================
REM DB_USER will be replaced 
REM ==========================================
set DB_USER=@DB_USER@

REM ==========================================
REM DB_SCHEMA will be replaced 
REM ==========================================
set DB_SCHEMA=@SCHEMA@


:INPUT_USERNAME
if "%DB_USER%"==""  (
  set /p DB_USER=Please enter username: 
  goto INPUT_USERNAME
)

:INPUT_SCHEMANAME
if "%DB_SCHEMA%"==""  (
  set /p DB_SCHEMA=The default value of the common database schema name is dbUserId. Enter schema name to cdbSchemaName value that you are using in the profile creation if it is different than default else hit Enter key:
)

if "%DB_SCHEMA%" == ""  (
  set DB_SCHEMA=%DB_USER%
) 

db2cmd /w /c /i .\createDBTables.bat %DB_USER% %DB_NAME% %DB_SCHEMA% %DB_CREATE%

if not %ERRORLEVEL%==0 (
    goto PRINT_USAGE
) else (
    goto END 
)

:PRINT_USAGE

REM Print usage messages
echo.
echo ========================================================================================
echo Usage: configCommonDB.bat [createDB]
echo.
echo Parameters:
echo    createDB    - specify whether or not to  create a new db 
echo Note:
echo     Make sure database setup correctly
echo     On windows system make sure DB2 executables are in the classpath before executing
echo     this script or manageprofiles  command or PMT tool. This is needed to
echo     invoke db2cmd command for  creating a new database.
echo     Always run configCommonDB.bat script rather than running individual sql script else 
echo     some tables might be created in wrong schema                   
echo ========================================================================================

goto END

:END

cd /d "%CUR_DIR%"

endlocal

